@@ -628,6 +628,7 @@ class BooksModel(QAbstractTableModel):  # {{{
     def get_book_display_info(self, idx):
         mi = self.db.get_metadata(idx)
         mi.size = mi._proxy_metadata.book_size
+        mi.book_display_info_is_from_device = False
         mi.cover_data = ('jpg', self.cover(idx))
         mi.id = self.db.id(idx)
         mi.field_metadata = self.db.field_metadata
@@ -1003,10 +1004,26 @@ class BooksModel(QAbstractTableModel):  # {{{
                                                      self.db.id(idx))
             return f
 
+        def template_tooltip(key, orig_tt_func):
+            def f(idx):
+                try:
+                    template = self.db.new_api.pref('column_tooltip_templates', {}).get(key, '')
+                    if template:
+                        global_vars = {'column_lookup_name': key, 'original_text': orig_tt_func(idx)}
+                        mi = self.db.new_api.get_proxy_metadata(self.db.data.index_to_id(idx))
+                        return self.formatter.safe_format(
+                                template, {}, _('tooltip template error'), mi, global_vars=global_vars)
+                except Exception as e:
+                    return str(e)
+                return orig_tt_func(idx)
+            return f
+
         for f, allow_half in iteritems(rating_fields):
             tc[f] = stars_tooltip(self.dc[f], allow_half)
         for f in bool_fields:
             tc[f] = bool_tooltip(f)
+        for f in self.db.new_api.pref('column_tooltip_templates', {}):
+            tc[f] = template_tooltip(f, tc[f])
         # build a index column to data converter map, to remove the string lookup in the data loop
         self.column_to_dc_map = [self.dc[col] for col in self.column_map]
         self.column_to_tc_map = [tc[col] for col in self.column_map]
@@ -1722,6 +1739,7 @@ class DeviceBooksModel(BooksModel):  # {{{
         mi.device_collections = list(item.device_collections)
         mi.tags = list(getattr(item, 'tags', []))
         mi.comments = getattr(item, 'comments', None)
+        mi.book_display_info_is_from_device = True
         series = getattr(item, 'series', None)
         if series:
             sidx = getattr(item, 'series_index', 0)
