@@ -5,8 +5,6 @@ __license__   = 'GPL v3'
 __copyright__ = '2011, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
-from operator import attrgetter
-
 from qt.core import (
     QAbstractListModel,
     QAbstractTableModel,
@@ -29,6 +27,7 @@ from calibre.ebooks.metadata.sources.prefs import msprefs
 from calibre.gui2 import error_dialog, question_dialog
 from calibre.gui2.preferences import ConfigWidgetBase, test_widget
 from calibre.gui2.preferences.metadata_sources_ui import Ui_Form
+from calibre.utils.icu import primary_sort_key
 from calibre.utils.localization import ngettext
 from polyglot.builtins import iteritems
 
@@ -43,10 +42,16 @@ class SourcesModel(QAbstractTableModel):  # {{{
         self.enabled_overrides = {}
         self.cover_overrides = {}
 
+    def reload_plugins(self):
+        self.beginResetModel()
+        self.plugins = list(all_metadata_plugins())
+        self.plugins.sort(key=lambda p: primary_sort_key(p.name))
+        self.endResetModel()
+
     def initialize(self):
         self.beginResetModel()
         self.plugins = list(all_metadata_plugins())
-        self.plugins.sort(key=attrgetter('name'))
+        self.plugins.sort(key=lambda p: primary_sort_key(p.name))
         self.enabled_overrides = {}
         self.cover_overrides = {}
         self.endResetModel()
@@ -68,7 +73,7 @@ class SourcesModel(QAbstractTableModel):  # {{{
     def data(self, index, role):
         try:
             plugin = self.plugins[index.row()]
-        except:
+        except Exception:
             return None
         col = index.column()
 
@@ -96,7 +101,7 @@ class SourcesModel(QAbstractTableModel):  # {{{
     def setData(self, index, val, role):
         try:
             plugin = self.plugins[index.row()]
-        except:
+        except Exception:
             return False
         col = index.column()
         ret = False
@@ -206,7 +211,7 @@ class FieldsModel(QAbstractListModel):  # {{{
     def data(self, index, role):
         try:
             field = self.fields[index.row()]
-        except:
+        except Exception:
             return None
         if role == Qt.ItemDataRole.DisplayRole:
             return self.descs.get(field, field)
@@ -236,7 +241,7 @@ class FieldsModel(QAbstractListModel):  # {{{
     def setData(self, index, val, role):
         try:
             field = self.fields[index.row()]
-        except:
+        except Exception:
             return False
         ret = False
         if role == Qt.ItemDataRole.CheckStateRole:
@@ -347,11 +352,21 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         m.addAction(_('Tags')).triggered.connect(self.change_tag_map_rules)
         m.addAction(_('Authors')).triggered.connect(self.change_author_map_rules)
         m.addAction(_('Publisher')).triggered.connect(self.change_publisher_map_rules)
-        m.addAction(_('Series')).triggered.connect(self.change_series_map_rules)
+        m.addAction(ngettext('Series', 'Series', 1)).triggered.connect(self.change_series_map_rules)
         self.map_rules_button.setMenu(m)
         l = self.page.layout()
         l.setStretch(0, 1)
         l.setStretch(1, 1)
+        self.add_new_source_button.clicked.connect(self.add_new_source)
+
+    def add_new_source(self):
+        from calibre.gui2.dialogs.plugin_updater import FILTER_NOT_INSTALLED, Category, PluginUpdaterDialog
+        d = PluginUpdaterDialog(self, initial_filter=FILTER_NOT_INSTALLED, initial_category=Category.MetadataSource)
+        d.warn_about_neededing_restart = False
+        d.exec()
+        if d.number_installed:
+            self.sources_model.reload_plugins()
+            self.fields_model.initialize()
 
     def context_menu(self, pos):
         m = QMenu(self)
@@ -378,7 +393,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
     def pc_finished(self):
         try:
             self.pc.finished.disconnect()
-        except:
+        except Exception:
             pass
         self.stack.setCurrentIndex(0)
         self.stack.removeWidget(self.pc)
